@@ -9,7 +9,7 @@ use parent 'Module::Build';
 use Ado::Build qw(
   process_etc_files process_public_files
   process_templates_files create_build_script
-  ACTION_perltidy ACTION_submit);
+  ACTION_perltidy ACTION_submit PERL_DIRS);
 
 
 1;
